==> mule-extension-ast-loader-1.8.7-20250624.174335-25-sources.jar: org/mule/runtime/ast/extension/internal/VariableElementAST.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.ast.extension.internal;

import static java.util.Optional.empty;
import static java.util.Optional.of;
import static java.util.Optional.ofNullable;

import org.mule.runtime.module.extension.api.loader.java.type.AnnotationValueFetcher;
import org.mule.runtime.module.extension.api.loader.java.type.ExtensionParameter;
import org.mule.runtime.module.extension.api.loader.java.type.Type;

import javax.annotation.processing.ProcessingEnvironment;
import javax.lang.model.element.VariableElement;

import java.lang.annotation.Annotation;
import java.util.Optional;
import java.util.stream.Stream;

/**
 * Wrapper of {@link VariableElement} representing {@link ExtensionParameter}.
 *
 * @since 1.0
 */
public abstract class VariableElementAST implements ExtensionParameter {

  private final VariableElement param;
  private final ProcessingEnvironment processingEnvironment;
  private final ASTUtils astUtils;

  VariableElementAST(VariableElement param, ProcessingEnvironment processingEnvironment) {
    this.param = param;
    this.processingEnvironment = processingEnvironment;
    this.astUtils = new ASTUtils(processingEnvironment);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public String getName() {
    return param.getSimpleName().toString();
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public <A extends Annotation> Optional<A> getAnnotation(Class<A> annotationClass) {
    return ofNullable(param.getAnnotation(annotationClass));
  }

  @Override
  public boolean isAnnotatedWith(Class<? extends Annotation> annotation) {
    return param == null ? false : param.getAnnotation(annotation) != null;
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public <A extends Annotation> Optional<AnnotationValueFetcher<A>> getValueFromAnnotation(Class<A> annotationClass) {
    if (this.isAnnotatedWith(annotationClass)) {
      return of(astUtils.fromAnnotation(annotationClass, param));
    } else {
      return empty();
    }
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public Stream<Type> getAnnotations() {
    return param.getAnnotationMirrors().stream().map(ann -> new ASTType(ann.getAnnotationType(), processingEnvironment));
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public ASTType getType() {
    return new ASTType(param.asType(), processingEnvironment);
  }

  @Override
  public Optional<VariableElement> getElement() {
    return of(param);
  }
}

==> mule-extension-ast-loader-1.9.0-20250507.230426-220-sources.jar: org/mule/runtime/ast/extension/internal/VariableElementAST.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.ast.extension.internal;

import static java.util.Optional.empty;
import static java.util.Optional.of;
import static java.util.Optional.ofNullable;

import org.mule.runtime.module.extension.api.loader.java.type.AnnotationValueFetcher;
import org.mule.runtime.module.extension.api.loader.java.type.ExtensionParameter;
import org.mule.runtime.module.extension.api.loader.java.type.Type;

import javax.annotation.processing.ProcessingEnvironment;
import javax.lang.model.element.VariableElement;

import java.lang.annotation.Annotation;
import java.util.Optional;
import java.util.stream.Stream;

/**
 * Wrapper of {@link VariableElement} representing {@link ExtensionParameter}.
 *
 * @since 1.0
 */
public abstract class VariableElementAST implements ExtensionParameter {

  private final VariableElement param;
  private final ProcessingEnvironment processingEnvironment;
  private final ASTUtils astUtils;

  VariableElementAST(VariableElement param, ProcessingEnvironment processingEnvironment) {
    this.param = param;
    this.processingEnvironment = processingEnvironment;
    this.astUtils = new ASTUtils(processingEnvironment);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public String getName() {
    return param.getSimpleName().toString();
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public <A extends Annotation> Optional<A> getAnnotation(Class<A> annotationClass) {
    return ofNullable(param.getAnnotation(annotationClass));
  }

  @Override
  public boolean isAnnotatedWith(Class<? extends Annotation> annotation) {
    return param != null && param.getAnnotation(annotation) != null;
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public <A extends Annotation> Optional<AnnotationValueFetcher<A>> getValueFromAnnotation(Class<A> annotationClass) {
    if (this.isAnnotatedWith(annotationClass)) {
      return of(astUtils.fromAnnotation(annotationClass, param));
    } else {
      return empty();
    }
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public Stream<Type> getAnnotations() {
    return param.getAnnotationMirrors().stream().map(ann -> new ASTType(ann.getAnnotationType(), processingEnvironment));
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public ASTType getType() {
    return new ASTType(param.asType(), processingEnvironment);
  }

  @Override
  public Optional<VariableElement> getElement() {
    return of(param);
  }
}
